@@ -34,6 +34,25 @@ from hivemind.gui_widgets import StatusAction
 import hivemind.sysconfig as sysconfig
 import hivemind.settings as settings
 
+
+def _setShortcut(action, shortcut):
+    '''
+    Set shortcut to action
+    @type action: QAction
+    @type shortcut: string or int
+    '''
+    #pylint: disable = E1103
+    shortcut = unicode(QKeySequence(shortcut).toString()).lower()
+    if 'return' in shortcut:
+        shortcut = [shortcut, shortcut.replace('return', 'enter')]
+    if 'enter' in shortcut:
+        shortcut = [shortcut, shortcut.replace('enter', 'return')]
+    if isinstance(shortcut, list):
+        action.setShortcuts(shortcut)
+    else:
+        action.setShortcut(shortcut)
+
+
 class ActionBag(QObject):
     '''
     Action bag for actions storing
@@ -68,8 +87,9 @@ class ActionBag(QObject):
         self._initializeActions()
         self._updateShortcuts()
         if sysconfig.PLATFORM == 'maemo':
-            self._setMaemoShortcuts()
             self._initializeMaemoActions()
+        else:
+            self._addEllipsesToActionText()
         settings.connect(self._updateRecentFileActions)
         settings.connect(self._updateShortcuts)
 
@@ -171,42 +191,20 @@ class ActionBag(QObject):
                 settings.get('selectDownNodeShortcut'))
         self.__selectRootNodeAction = self.createAction('',
                 settings.get('selectRootNodeShortcut'))
-        self.__startSmartConferenceRobot = self.createAction('Join SmartConference')
-        self.__stopSmartConferenceRobot = self.createAction('Leave SmartConference')
-
-    def _setShortcut(self, action, shortcut):
-        '''
-        Set shortcut to action
-        @type action: QAction
-        @type shortcut: string or int
-        '''
-        shortcut = unicode(QKeySequence(shortcut).toString()).lower()
-        if 'return' in shortcut:
-            shortcut = [shortcut, shortcut.replace('return', 'enter')]
-        if 'enter' in shortcut:
-            shortcut = [shortcut, shortcut.replace('enter', 'return')]
-        if isinstance(shortcut, list):
-            action.setShortcuts(shortcut)
-        else:
-            action.setShortcut(shortcut)
+        self.__startSmartConferenceRobot = self.createAction(self.tr('&Join SmartConference'))
+        self.__stopSmartConferenceRobot = self.createAction(self.tr('&Leave SmartConference'))
 
     def _updateShortcuts(self):
         '''Update action shortcuts'''
-        self._setShortcut(self.__editEdgeAction, settings.get('editEdgeShortcut'))
-        self._setShortcut(self.__editLabelAction, settings.get('editLabelShortcut'))
-        self._setShortcut(self.__editNodeAction, settings.get('editNodeShortcut'))
-        self._setShortcut(self.__editNodeIconsAction, settings.get('editNodeIconsShortcut'))
-        self._setShortcut(self.__foldNodeAction, settings.get('foldNodeShortcut'))
-        self._setShortcut(self.__addNodeAction, settings.get('addNodeShortcut'))
-        self._setShortcut(self.__removeNodeAction, settings.get('removeNodeShortcut'))
-        self._setShortcut(self.__editHyperlinkAction, settings.get('editHyperlinkShortcut'))
-        self._setShortcut(self.__openHyperlinkAction, settings.get('openHyperlinkShortcut'))
-
-    def _setMaemoShortcuts(self):
-        '''Set action shortcuts for Maemo'''
-        self.__enterTransferModeAction.setShortcut(Qt.Key_M)
-        self.__cancelTransferModeAction.setShortcut(Qt.Key_Q)
-        self.__putNodeAction.setShortcut(Qt.Key_A)
+        _setShortcut(self.__editEdgeAction, settings.get('editEdgeShortcut'))
+        _setShortcut(self.__editLabelAction, settings.get('editLabelShortcut'))
+        _setShortcut(self.__editNodeAction, settings.get('editNodeShortcut'))
+        _setShortcut(self.__editNodeIconsAction, settings.get('editNodeIconsShortcut'))
+        _setShortcut(self.__foldNodeAction, settings.get('foldNodeShortcut'))
+        _setShortcut(self.__addNodeAction, settings.get('addNodeShortcut'))
+        _setShortcut(self.__removeNodeAction, settings.get('removeNodeShortcut'))
+        _setShortcut(self.__editHyperlinkAction, settings.get('editHyperlinkShortcut'))
+        _setShortcut(self.__openHyperlinkAction, settings.get('openHyperlinkShortcut'))
 
     def _initializeMaemoActions(self):
         '''Initialize maemo actions'''
@@ -223,6 +221,21 @@ class ActionBag(QObject):
         self.__networkHelpAction.setEnabled(False)
         self._updateRecentFileActions()
 
+    def _addEllipsesToActionText(self):
+        '''Add ellipses to the text of the actions displaying dialogs'''
+        actionsWithEllipses = [
+                self.__fileOpenAction, self.__fileSaveAsAction,
+                self.__settingsAction, self.__exportToImageAction,
+                self.__addNodeAction, self.__addSiblingNodeBelowAction,
+                self.__addSiblingNodeAboveAction, self.__editNodeAction,
+                self.__editNodeIconsAction, self.__editLabelAction,
+                self.__editEdgeAction, self.__editAffiliationAction,
+                self.__startClientAction, self.__networkSettingsAction,
+                self.__printAction, self.__findAction,
+                self.__editHyperlinkAction, self.__startServiceAction]
+        for action in actionsWithEllipses:
+            action.setText(action.text() + '...')
+
     def _updateRecentFileActions(self):
         '''
         Update recentFileList of recent files
@@ -248,6 +261,7 @@ class ActionBag(QObject):
         '''
         action = QAction(text, self)
         if shortcut:
-            self._setShortcut(action, shortcut)
-        if icon: action.setIcon(QIcon.fromTheme(icon))
+            _setShortcut(action, shortcut)
+        if icon:
+            action.setIcon(QIcon.fromTheme(icon))
         return action
