@@ -19,8 +19,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA
-
-
 '''
 Abstract dialog classes
 '''
@@ -38,10 +36,13 @@ from hivemind.gui_widgets import SearchingTrMixin, SpecialTextEdit, SettingsCrea
 ScalingWidget, IconList, IconTable, LineEditBinder, ColorLabel
 from hivemind.network.network_models import AffiliationDelegate
 from twisted.words.protocols.jabber import jid
+from hivemind.smartconference.kp import SmartSpaceChecker
 
-'''Regexp for jid validation'''
+'''Regexp for jid'''
 VALID_JID = '[A-Za-z0-9._%+-]+@(?:[A-Za-z0-9-]+\\.)+[A-Za-z]{2,6}'
-VALID_HOST = '([A-Za-z0-9-]+\\.)+[A-Za-z]{2,6}'
+'''Regexp for hostname (http://tools.ietf.org/html/rfc952)'''
+VALID_HOST = ('^(([a-zA-Z]|[a-zA-Z][a-zA-Z0-9\-]*[a-zA-Z0-9])\\.)'
+        '*([A-Za-z]|[A-Za-z][A-Za-z0-9\-]*[A-Za-z0-9])$')
 
 
 def _showJIDErrorDialog(parent):
@@ -1416,3 +1417,77 @@ class EditHyperlinkDialog(CommonDialog):
         @rtype: dict
         '''
         return self.__newAttributes
+
+
+class SmartSpaceConnectionDialog(CommonDialog):
+    '''Dialog for inputting location of smart conference system'''
+
+    readable('name', 'host', 'port')
+
+    def __init__(self, parent = None):
+        '''
+        @param parent: Parent of the current dialog
+        '''
+        CommonDialog.__init__(self, parent)
+        self.__nameField = QLineEdit('X', self)
+        self.__ipField = QLineEdit('127.0.0.1', self)
+        self.__portField = QLineEdit('10010', self)
+        self.__name = 'X'
+        self.__host = '127.0.0.1'
+        self.__port = '10010'
+        self.__checker = SmartSpaceChecker(self)
+        self.__checker.found.connect(self._spaceFound)
+        self._initComponents()
+
+    def _initComponents(self):
+        '''Initialize components'''
+        self.setWindowTitle(self.tr('Connection to SmartSpace'))
+        mainLayout = QFormLayout()
+        mainLayout.addRow(self.tr('Space name'), self.__nameField)
+        mainLayout.addRow(self.tr('IP address'), self.__ipField)
+        mainLayout.addRow(self.tr('Port'), self.__portField)
+        mainLayout.addRow(self._buttonBox)
+        self.setLayout(mainLayout)
+
+    def _checkIp(self):
+        '''
+        Check contents of the ip field
+        @return: True if it is the IP address
+        @rtype: bool
+        '''
+        address = unicode(self.__ipField.text()).split('.')
+        if len(address) != 4: return False
+        for part in address:
+            try:
+                number = int(part)
+            except TypeError:
+                return False
+            if number < 0 or number > 255:
+                return False
+        return True
+
+    def _accept(self):
+        '''Accept handler'''
+        if not self._checkIp() or self.__nameField.text().isEmpty() or \
+                self.__portField.text().isEmpty():
+            QMessageBox.warning(self, self.tr('Input error'),
+                    self.tr('Please input all data correctly'))
+            return
+        self._buttonBox.setEnabled(False)
+        self.__host = unicode(self.__ipField.text())
+        self.__port = int(unicode(self.__portField.text()))
+        self.__name = unicode(self.__nameField.text())
+        self.__checker.check(self.__host, self.__port, self.__name)
+
+    def _spaceFound(self, found):
+        '''
+        This method is called when the search of the smart space is over
+        @param found: indication whether search was successfull or not
+        @type found: bool
+        '''
+        self._buttonBox.setEnabled(True)
+        if not found:
+            QMessageBox.warning(self, self.tr('Space not found'),
+                    self.tr('There is no smart space available at specified address'))
+            return
+        QDialog.accept(self)
