@@ -31,6 +31,7 @@ from hivemind.gui_widgets import MaemoSidePanel, FullScreenExitButton, MaemoNode
 from hivemind.attribute import readable
 import hivemind.settings as settings
 from hivemind.maemo.dialogs import MaemoExtendedMenuDialog, MaemoNetworkMainDialog
+from hivemind.smartconference.kp import M3_AVAILABLE
 
 
 class MaemoMainView(MainView):
@@ -162,6 +163,9 @@ class MaemoMainWindow(AbstractMainWindow):
         menu.addAction(self._actionBag.fileSaveAction)
         menu.addAction(self._actionBag.fileSaveAsAction)
         menu.addAction(self._actionBag.exportToImageAction)
+        if M3_AVAILABLE:
+            menu.addAction(self._actionBag.startSmartConferenceRobot)
+            menu.addAction(self._actionBag.stopSmartConferenceRobot)
         menu.addAction(self.__fullScreenAction)
         menu.addAction(self._actionBag.findAction)
         menu.addAction(self._actionBag.settingsAction)
