@@ -176,6 +176,8 @@ class NetworkController(QObject):
         self.__actionBag.startClientAction.setDisabled(state == 'collaboration')
         self.__actionBag.editAffiliationAction.setEnabled(state == 'collaboration' and
                 self.__isServiceRole)
+        self.__actionBag.networkSettingsAction.setDisabled(state == 'collaboration' and
+                not self.__isServiceRole)
 
     def publishCommand(self, command):
         '''
